@@ -6,7 +6,7 @@ require 'rack/builder'
 require 'sinatra/showexceptions'
 
 module Sinatra
-  VERSION = '0.9.2'
+  VERSION = '0.9.4'
 
   # The request object. See Rack::Request for more info:
   # http://rack.rubyforge.org/doc/classes/Rack/Request.html
@@ -23,7 +23,7 @@ module Sinatra
     # Override Rack 0.9.x's #params implementation (see #72 in lighthouse)
     def params
       self.GET.update(self.POST)
-    rescue EOFError => boom
+    rescue EOFError, Errno::ESPIPE
       self.GET
     end
   end
@@ -268,7 +268,7 @@ module Sinatra
       if layout
         data, options[:filename], options[:line] = lookup_layout(engine, layout, views)
         if data
-          output = __send__("render_#{engine}", layout, data, options, {}) { output }
+          output = __send__("render_#{engine}", layout, data, options, locals) { output }
         end
       end
 
@@ -922,7 +922,7 @@ module Sinatra
         servers = Array(self.server)
         servers.each do |server_name|
           begin
-            return Rack::Handler.get(server_name.capitalize)
+            return Rack::Handler.get(server_name.downcase)
           rescue LoadError
           rescue NameError
           end
@@ -951,7 +951,7 @@ module Sinatra
 
     public
       CALLERS_TO_IGNORE = [
-        /lib\/sinatra.*\.rb$/, # all sinatra code
+        /\/sinatra(\/(base|main|showexceptions|compat))?\.rb$/, # all sinatra code
         /\(.*\)/,              # generated code
         /custom_require\.rb$/, # rubygems require hacks
         /active_support/,      # active_support require hacks
@@ -977,7 +977,7 @@ module Sinatra
     set :raise_errors, true
     set :dump_errors, false
     set :clean_trace, true
-    set :show_exceptions, Proc.new { development? }
+    set :show_exceptions, false
     set :sessions, false
     set :logging, false
     set :methodoverride, false
@@ -1048,6 +1048,7 @@ module Sinatra
   # Base class for classic style (top-level) applications.
   class Default < Base
     set :raise_errors, Proc.new { test? }
+    set :show_exceptions, Proc.new { development? }
     set :dump_errors, true
     set :sessions, false
     set :logging, Proc.new { ! test? }
