@@ -1,6 +1,7 @@
 require File.dirname(__FILE__) + '/helper'
+require 'builder'
 
-describe "Builder Templates" do
+class BuilderTest < Test::Unit::TestCase
   def builder_app(&block)
     mock_app {
       set :views, File.dirname(__FILE__) + '/views'
