@@ -76,6 +76,12 @@ class TemplatesTest < Test::Unit::TestCase
     assert_equal "X\n= yield\nX\n", @app.templates[:layout][:template]
   end
 
+  it 'loads templates from specified views directory' do
+    render_app { render :test, :hello, :views => options.views + '/foo' }
+
+    assert_equal "from another views directory\n", body
+  end
+
   test 'use_in_file_templates simply ignores IO errors' do
     assert_nothing_raised {
       mock_app {
@@ -85,6 +91,22 @@ class TemplatesTest < Test::Unit::TestCase
 
     assert @app.templates.empty?
   end
+
+  it 'passes locals to the layout' do
+    mock_app {
+      template :my_layout do
+        'Hello <%= name %>!<%= yield %>'
+      end
+
+      get '/' do
+        erb '<p>content</p>', { :layout => :my_layout }, { :name => 'Mike'}
+      end
+    }
+
+    get '/'
+    assert ok?
+    assert_equal 'Hello Mike!<p>content</p>', body
+  end
 end
 
 # __END__ : this is not the real end of the script.
